@@ -140,20 +140,13 @@ class LeapLoader:
                 is_valid = False
 
         print_log = stdout_steam.getvalue()
-        if print_log is not None and print_log != "":
-            if general_error is None:
-                general_error = ""
-            else:
-                general_error += "\n\n"
-            general_error += "Print Log:\n"
-            general_error += print_log
-
         is_valid_for_model = bool(global_leap_binder.setup_container.custom_layers)
         model_setup = self.get_model_setup_response()
 
         return DatasetIntegParseResult(is_valid=is_valid, payloads=test_payloads,
                                        is_valid_for_model=is_valid_for_model, setup=setup_response,
-                                       model_setup=model_setup, general_error=general_error)
+                                       model_setup=model_setup, general_error=general_error,
+                                       print_log=print_log)
 
     @staticmethod
     def _check_preprocess() -> DatasetTestResultPayload:
